aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/gdisp/SSD1289
diff options
context:
space:
mode:
authorJoel Bodenmann <joel@unormal.org>2012-11-19 21:55:08 +0100
committerJoel Bodenmann <joel@unormal.org>2012-11-19 21:55:08 +0100
commit9f2a7c36d9e37364168455c7ffc3440ce40144dc (patch)
treefa2ff979dc6b5c945dd9f8844c98286c78125a62 /drivers/gdisp/SSD1289
parentcafb45474528f3246cc4e1d39deef4677fe69848 (diff)
downloaduGFX-9f2a7c36d9e37364168455c7ffc3440ce40144dc.tar.gz
uGFX-9f2a7c36d9e37364168455c7ffc3440ce40144dc.tar.bz2
uGFX-9f2a7c36d9e37364168455c7ffc3440ce40144dc.zip
replaced get_bus by aquire_bus
Diffstat (limited to 'drivers/gdisp/SSD1289')
-rw-r--r--drivers/gdisp/SSD1289/gdisp_lld.c14
-rw-r--r--drivers/gdisp/SSD1289/gdisp_lld_board_example.h4
-rw-r--r--drivers/gdisp/SSD1289/gdisp_lld_board_example_fsmc.h2
-rw-r--r--drivers/gdisp/SSD1289/gdisp_lld_board_firebullstm32f103.h2
4 files changed, 11 insertions, 11 deletions
diff --git a/drivers/gdisp/SSD1289/gdisp_lld.c b/drivers/gdisp/SSD1289/gdisp_lld.c
index f70d585c..f785a532 100644
--- a/drivers/gdisp/SSD1289/gdisp_lld.c
+++ b/drivers/gdisp/SSD1289/gdisp_lld.c
@@ -161,7 +161,7 @@ bool_t GDISP_LLD(init)(void) {
delayms(20);
// Get the bus for the following initialisation commands
- get_bus();
+ aquire_bus();
write_reg(0x0000,0x0001); delay(5);
write_reg(0x0003,0xA8A4); delay(5);
@@ -241,7 +241,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
if (x < GDISP.clipx0 || y < GDISP.clipy0 || x >= GDISP.clipx1 || y >= GDISP.clipy1) return;
#endif
- get_bus();
+ aquire_bus();
set_cursor(x, y);
write_reg(0x0022, color);
release_bus();
@@ -276,7 +276,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
void GDISP_LLD(clear)(color_t color) {
unsigned i;
- get_bus();
+ aquire_bus();
set_cursor(0, 0);
stream_start();
for(i = 0; i < GDISP_SCREEN_WIDTH * GDISP_SCREEN_HEIGHT; i++)
@@ -310,7 +310,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
area = cx*cy;
- get_bus();
+ aquire_bus();
set_viewport(x, y, cx, cy);
stream_start();
for(i = 0; i < area; i++)
@@ -346,7 +346,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
if (y+cy > GDISP.clipy1) cy = GDISP.clipy1 - y;
#endif
- get_bus();
+ aquire_bus();
set_viewport(x, y, cx, cy);
stream_start();
@@ -379,7 +379,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
if (x < 0 || x >= GDISP.Width || y < 0 || y >= GDISP.Height) return 0;
#endif
- get_bus();
+ aquire_bus();
set_cursor(x, y);
stream_start();
color = read_data(); // dummy read
@@ -419,7 +419,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
abslines = lines < 0 ? -lines : lines;
- get_bus();
+ aquire_bus();
if (abslines >= cy) {
abslines = cy;
gap = 0;
diff --git a/drivers/gdisp/SSD1289/gdisp_lld_board_example_fsmc.h b/drivers/gdisp/SSD1289/gdisp_lld_board_example_fsmc.h
index d3532b76..5541a8cd 100644
--- a/drivers/gdisp/SSD1289/gdisp_lld_board_example_fsmc.h
+++ b/drivers/gdisp/SSD1289/gdisp_lld_board_example_fsmc.h
@@ -116,7 +116,7 @@ static __inline void set_backlight(uint8_t percent) {
*
* @notapi
*/
-static __inline void get_bus(void) {
+static __inline void aquire_bus(void) {
/* Nothing to do here */
}
diff --git a/drivers/gdisp/SSD1289/gdisp_lld_board_firebullstm32f103.h b/drivers/gdisp/SSD1289/gdisp_lld_board_firebullstm32f103.h
index 7d20c341..ad445f9e 100644
--- a/drivers/gdisp/SSD1289/gdisp_lld_board_firebullstm32f103.h
+++ b/drivers/gdisp/SSD1289/gdisp_lld_board_firebullstm32f103.h
@@ -88,7 +88,7 @@ static __inline void set_backlight(uint8_t percent) {
*
* @notapi
*/
-static __inline void get_bus(void) {
+static __inline void aquire_bus(void) {
/* Nothing to do here */
}
diff --git a/drivers/gdisp/SSD1289/gdisp_lld_board_example.h b/drivers/gdisp/SSD1289/gdisp_lld_board_example.h
index 6dcad1b5..05f7cefa 100644
--- a/drivers/gdisp/SSD1289/gdisp_lld_board_example.h
+++ b/drivers/gdisp/SSD1289/gdisp_lld_board_example.h
@@ -68,8 +68,8 @@ static __inline void set_backlight(uint8_t percent) {
*
* @notapi
*/
-static __inline void get_bus(void) {
-#error "SSD1289: You must supply a definition for get_bus for your board"
+static __inline void aquire_bus(void) {
+#error "SSD1289: You must supply a definition for aquire_bus for your board"
}
/**